@@ -171,3 +171,90 @@ from_to <- function(start_time, stop_time, dist, arrive=TRUE){
     }
   }
 }
+
+#' @importFrom R6 R6Class
+simmer.schedule <- R6Class("simmer.schedule",
+  public = list(
+    initialize = function(timetable, values, period=Inf) { 
+      if (!is.numeric(c(timetable, period, values)))
+        stop("all arguments must be numeric")
+      if (is.unsorted(timetable) || !all(period >= timetable) ||
+          (timetable[length(timetable)] == period + timetable[1]))
+        stop("invalid timetable")
+      if (length(timetable) != length(values))
+        stop("vector lengths must agree")
+      if (length(timetable) < 2)
+        stop("at least two values required")
+      if (!all(values >= 0))
+        stop("invalid values")
+      private$timetable <- timetable
+      private$values <- replace(values, values==Inf, -1)
+      private$period <- replace(period, period==Inf, -1)
+      private$n <- length(private$timetable)
+      
+      if (private$period < 0) private$compose_non_periodic()
+      else private$compose_periodic()
+      self
+    },
+    
+    print = function() {
+      cat(paste0("simmer schedule\n",
+                 "{ timetable: ", paste(private$timetable, collapse=" "), 
+                 " | period: ", ifelse(private$period>0, private$period, Inf), " }\n",
+                 "{ values: ", paste(private$values, collapse=" "), " }\n"))
+    },
+    
+    get_schedule = function() { private$schedule }
+  ),
+  
+  private = list(
+    timetable = NA,
+    period = NA,
+    values = NA,
+    n = NA,
+    schedule = NA,
+    
+    compose_periodic = function() {
+      intervals <- c(private$timetable[1], diff(private$timetable), 
+                     private$timetable[1] + private$period - private$timetable[private$n])
+      values <- c(private$values, private$values[1])
+      if (private$timetable[1] == 0) init <- private$values[1]
+      else init <- private$values[private$n]
+      private$schedule <- list(
+        init = init,
+        intervals = intervals,
+        values = values,
+        period = private$period)
+    },
+    
+    compose_non_periodic = function() {
+      private$schedule <- list(
+        init = 0,
+        intervals = c(private$timetable[1], diff(private$timetable)),
+        values = private$values,
+        period = private$period)
+    }
+  )
+)
+
+#' Generate a scheduling object
+#' 
+#' Resource convenience function to generate a scheduling object from a timetable specification.
+#'
+#' @param timetable absolute points in time in which the desired value changes.
+#' @param values one value for each point in time.
+#' @param period period of repetition.
+#' 
+#' @return Returns a Schedule object.
+#' @seealso \link{add_resource}.
+#' @export
+#' 
+#' @examples
+#' # Schedule 3 units from 8 to 16 h
+#' #          2 units from 16 to 24 h
+#' #          1 units from 24 to 8 h
+#' capacity_schedule <- schedule(c(8, 16, 24), c(3, 2, 1), period=24)
+#' 
+#' env <- simmer() %>%
+#'   add_resource("dummy", capacity_schedule)
+schedule <- function(timetable, values, period=Inf) simmer.schedule$new(timetable, values, period)
