@@ -1,7 +1,7 @@
 #' @useDynLib simmer
 #' @importFrom R6 R6Class
 #' @importFrom Rcpp evalCpp
-Simmer <- R6Class("Simmer",
+Simmer <- R6Class("simmer",
   public = list(
     name = NA,
     
@@ -13,7 +13,7 @@ Simmer <- R6Class("Simmer",
     
     print = function() {
       cat(paste0(
-        "Simmer environment: ", self$name,
+        "simmer environment: ", self$name,
         " | now: ", self$now(), " | next: ", self$peek(), "\n"
       ))
       for (name in names(private$res))
@@ -40,10 +40,13 @@ Simmer <- R6Class("Simmer",
     
     now = function() { now_(private$sim_obj) },
     
-    peek = function() {
-      ret <- peek_(private$sim_obj)
-      if (ret >= 0) ret
-      else Inf
+    peek = function(steps=1, verbose=F) {
+      steps <- evaluate_value(steps)
+      verbose <- evaluate_value(verbose)
+      steps <- replace(steps, steps==Inf, -1)
+      ret <- as.data.frame(peek_(private$sim_obj, steps))
+      if (!verbose) ret$time
+      else ret # nocov
     },
     
     step = function() {
@@ -53,33 +56,57 @@ Simmer <- R6Class("Simmer",
     
     run = function(until=1000) {
       until <- evaluate_value(until)
-      if(!is.finite(until)) until <- 1000
-      
+      until <- replace(until, until==Inf, -1)
       run_(private$sim_obj, until)
       self
     },
     
     add_resource = function(name, capacity=1, queue_size=Inf, mon=TRUE,
                             preemptive=FALSE, preempt_order="fifo") {
+      if (!preempt_order %in% c("fifo", "lifo"))
+        stop("preempt order '", preempt_order, "' not supported")
       name <- evaluate_value(name)
       capacity <- evaluate_value(capacity)
+      capacity_schedule <- NA
       queue_size <- evaluate_value(queue_size)
-      if (is.infinite(capacity)) capacity <- -1
-      if (is.infinite(queue_size)) queue_size <- -1
+      queue_size_schedule <- NA
       mon <- evaluate_value(mon)
       preemptive <- evaluate_value(preemptive)
       preempt_order <- evaluate_value(preempt_order)
-      if (!preempt_order %in% c("fifo", "lifo"))
-        stop("preempt order '", preempt_order, "' not supported")
+      
+      if (is.numeric(capacity) && is.infinite(capacity))
+        capacity <- -1
+      else if (inherits(capacity, "simmer.schedule")) {
+        capacity_schedule <- capacity
+        capacity <- capacity_schedule$get_schedule()$init
+      }
+      
+      if (is.numeric(queue_size) && is.infinite(queue_size))
+        queue_size <- -1
+      else if (inherits(queue_size, "simmer.schedule")) {
+        queue_size_schedule <- queue_size
+        queue_size <- queue_size_schedule$get_schedule()$init
+      }
       
       ret <- add_resource_(private$sim_obj, name, capacity, queue_size, mon,
                            preemptive, preempt_order)
       if (ret) private$res[[name]] <- mon
+      
+      if (inherits(capacity_schedule, "simmer.schedule"))
+        add_resource_manager_(private$sim_obj, name, "capacity",
+                              capacity_schedule$get_schedule()$intervals,
+                              capacity_schedule$get_schedule()$values,
+                              capacity_schedule$get_schedule()$period)
+      if (inherits(queue_size_schedule, "simmer.schedule"))
+        add_resource_manager_(private$sim_obj, name, "queue_size",
+                              queue_size_schedule$get_schedule()$intervals,
+                              queue_size_schedule$get_schedule()$values,
+                              queue_size_schedule$get_schedule()$period)
       self
     },
     
     add_generator = function(name_prefix, trajectory, dist, mon=1) {
-      if (!inherits(trajectory, "Trajectory"))
+      if (!inherits(trajectory, "simmer.trajectory"))
         stop("not a trajectory")
       name_prefix <- evaluate_value(name_prefix)
       mon <- evaluate_value(mon)
@@ -130,28 +157,58 @@ Simmer <- R6Class("Simmer",
                       value = numeric())
     },
     
-    get_mon_resources = function() {
+    get_mon_resources = function(data="counts") {
+      if (all(!data %in% c("counts", "limits")))
+        stop("parameter 'data' should be 'counts', 'limits' or both")
       if (sum(private$res>0))
         do.call(rbind,
           lapply(names(private$res[private$res>0]), function(i) {
             monitor_data <- as.data.frame(
-              get_mon_resource_(private$sim_obj, i)
+              if (all(data %in% "counts"))
+                get_mon_resource_counts_(private$sim_obj, i)
+              else if (all(data %in% "limits"))
+                get_mon_resource_limits_(private$sim_obj, i)
+              else
+                get_mon_resource_(private$sim_obj, i)
             )
             tryCatch({
-              monitor_data$system <- monitor_data$server + monitor_data$queue
+              if (all(data %in% "limits")) {
+                monitor_data$server <- 
+                  replace(monitor_data$server, monitor_data$server==-1, Inf)
+                monitor_data$queue <- 
+                  replace(monitor_data$queue, monitor_data$queue==-1, Inf)
+                monitor_data$system <- monitor_data$server + monitor_data$queue
+              } else if (all(c("counts", "limits") %in% data)) {
+                monitor_data$capacity <- 
+                  replace(monitor_data$capacity, monitor_data$capacity==-1, Inf)
+                monitor_data$queue_size <- 
+                  replace(monitor_data$queue_size, monitor_data$queue_size==-1, Inf)
+                monitor_data$system <- monitor_data$server + monitor_data$queue
+                monitor_data$limit <- monitor_data$capacity + monitor_data$queue_size
+              } else monitor_data$system <- monitor_data$server + monitor_data$queue
               monitor_data$resource <- i
             }, error = function(e) {
               monitor_data$system <<- numeric()
+              if (all(data %in% c("counts", "limits")))
+                monitor_data$limit <<- numeric()
               monitor_data$resource <<- character()
             })
             monitor_data
           })
         )
-      else data.frame(time = numeric(),
-                      server = numeric(),
-                      queue = numeric(), 
-                      system = numeric(), 
-                      resource = character())
+      else {
+        monitor_data <- data.frame(time = numeric(),
+                                   server = numeric(),
+                                   queue = numeric())
+        if (all(c("counts", "limits") %in% data)) {
+          monitor_data$capacity <- numeric()
+          monitor_data$queue_size <- numeric()
+          monitor_data$system <- numeric()
+          monitor_data$limit <- numeric()
+        } else monitor_data$system <- numeric()
+        monitor_data$resource <- character()
+        monitor_data
+      }
     },
     
     get_n_generated = function(name) { 
@@ -198,7 +255,7 @@ Simmer <- R6Class("Simmer",
 #' @param verbose enable showing activity information.
 #' 
 #' @return Returns a simulation environment.
-#' @seealso Other methods to deal with a simulation environment:
+#' @seealso Other methods for dealing with a simulation environment:
 #' \link{reset}, \link{now}, \link{peek}, \link{onestep}, \link{run}, 
 #' \link{add_resource}, \link{add_generator}, \link{get_mon_arrivals}, \link{get_mon_attributes},
 #' \link{get_mon_resources}, \link{get_n_generated}, \link{get_capacity}, \link{get_queue_size},
@@ -239,7 +296,7 @@ simmer <- function(name="anonymous", verbose=FALSE) Simmer$new(name, verbose)
 #' @param env the simulation environment.
 #' 
 #' @return Returns the simulation environment.
-#' @seealso Other methods to deal with a simulation environment:
+#' @seealso Other methods for dealing with a simulation environment:
 #' \link{simmer}, \link{now}, \link{peek}, \link{onestep}, \link{run}, 
 #' \link{add_resource}, \link{add_generator}, \link{get_mon_arrivals}, \link{get_mon_attributes},
 #' \link{get_mon_resources}, \link{get_n_generated}, \link{get_capacity}, \link{get_queue_size},
@@ -254,7 +311,7 @@ reset <- function(env) env$reset()
 #' @param env the simulation environment.
 #' 
 #' @return Returns a numeric value.
-#' @seealso Other methods to deal with a simulation environment:
+#' @seealso Other methods for dealing with a simulation environment:
 #' \link{simmer}, \link{reset}, \link{peek}, \link{onestep}, \link{run}, 
 #' \link{add_resource}, \link{add_generator}, \link{get_mon_arrivals}, \link{get_mon_attributes},
 #' \link{get_mon_resources}, \link{get_n_generated}, \link{get_capacity}, \link{get_queue_size},
@@ -262,20 +319,22 @@ reset <- function(env) env$reset()
 #' @export
 now <- function(env) env$now()
 
-#' Peek the next event's time
+#' Peek next events
 #'
-#' Gets the time of the next scheduled event.
+#' Looks for future events in the event queue.
 #' 
 #' @param env the simulation environment.
+#' @param steps number of steps to peek.
+#' @param verbose show additional information (i.e., the name of the process) about future events.
 #' 
-#' @return Returns a numeric value.
-#' @seealso Other methods to deal with a simulation environment:
+#' @return Returns numeric values if `verbose=F` and a data frame otherwise.
+#' @seealso Other methods for dealing with a simulation environment:
 #' \link{simmer}, \link{reset}, \link{now}, \link{onestep}, \link{run}, 
 #' \link{add_resource}, \link{add_generator}, \link{get_mon_arrivals}, \link{get_mon_attributes},
 #' \link{get_mon_resources}, \link{get_n_generated}, \link{get_capacity}, \link{get_queue_size},
 #' \link{get_server_count}, \link{get_queue_count}.
 #' @export
-peek <- function(env) env$peek()
+peek <- function(env, steps=1, verbose=F) env$peek(steps, verbose)
 
 #' Step the simulation
 #'
@@ -284,7 +343,7 @@ peek <- function(env) env$peek()
 #' @param env the simulation environment.
 #' 
 #' @return Returns the simulation environment.
-#' @seealso Other methods to deal with a simulation environment:
+#' @seealso Other methods for dealing with a simulation environment:
 #' \link{simmer}, \link{reset}, \link{now}, \link{peek}, \link{run}, 
 #' \link{add_resource}, \link{add_generator}, \link{get_mon_arrivals}, \link{get_mon_attributes},
 #' \link{get_mon_resources}, \link{get_n_generated}, \link{get_capacity}, \link{get_queue_size},
@@ -300,7 +359,7 @@ onestep <- function(env) env$step()
 #' @param until stop time.
 #' 
 #' @return Returns the simulation environment.
-#' @seealso Other methods to deal with a simulation environment:
+#' @seealso Other methods for dealing with a simulation environment:
 #' \link{simmer}, \link{reset}, \link{now}, \link{peek}, \link{onestep}, 
 #' \link{add_resource}, \link{add_generator}, \link{get_mon_arrivals}, \link{get_mon_attributes},
 #' \link{get_mon_resources}, \link{get_n_generated}, \link{get_capacity}, \link{get_queue_size},
@@ -326,7 +385,8 @@ run <- function(env, until=1000) env$run(until)
 #' are preempted first).
 #' 
 #' @return Returns the simulation environment.
-#' @seealso Other methods to deal with a simulation environment:
+#' @seealso Convenience functions: \link{schedule}.
+#' Other methods for dealing with a simulation environment:
 #' \link{simmer}, \link{reset}, \link{now}, \link{peek}, \link{onestep}, \link{run}, 
 #' \link{add_generator}, \link{get_mon_arrivals}, \link{get_mon_attributes},
 #' \link{get_mon_resources}, \link{get_n_generated}, \link{get_capacity}, \link{get_queue_size},
@@ -347,7 +407,8 @@ add_resource <- function(env, name, capacity=1, queue_size=Inf, mon=TRUE,
 #' @param mon whether the simulator must monitor the generated arrivals or not (0=no monitoring, 1=simple arrival monitoring, 2=level 1 + arrival attribute montoring)
 #' 
 #' @return Returns the simulation environment.
-#' @seealso Other methods to deal with a simulation environment:
+#' @seealso Convenience functions: \link{at}, \link{every}, \link{from}, 
+#' \link{to}, \link{from_to}. Other methods for dealing with a simulation environment:
 #' \link{simmer}, \link{reset}, \link{now}, \link{peek}, \link{onestep}, \link{run}, 
 #' \link{add_resource}, \link{get_mon_arrivals}, \link{get_mon_attributes},
 #' \link{get_mon_resources}, \link{get_n_generated}, \link{get_capacity}, \link{get_queue_size},
@@ -364,7 +425,7 @@ add_generator <- function(env, name_prefix, trajectory, dist, mon=1)
 #' @param per_resource whether the activity should be reported on a per-resource basis (by default: FALSE).
 #' 
 #' @return Returns a data frame.
-#' @seealso Other methods to deal with a simulation environment:
+#' @seealso Other methods for dealing with a simulation environment:
 #' \link{simmer}, \link{reset}, \link{now}, \link{peek}, \link{onestep}, \link{run}, 
 #' \link{add_resource}, \link{add_generator}, \link{get_mon_attributes},
 #' \link{get_mon_resources}, \link{get_n_generated}, \link{get_capacity}, \link{get_queue_size},
@@ -380,7 +441,7 @@ get_mon_arrivals <- function(env, per_resource=FALSE)
 #' @param env the simulation environment (or a list of environments).
 #' 
 #' @return Returns a data frame.
-#' @seealso Other methods to deal with a simulation environment:
+#' @seealso Other methods for dealing with a simulation environment:
 #' \link{simmer}, \link{reset}, \link{now}, \link{peek}, \link{onestep}, \link{run}, 
 #' \link{add_resource}, \link{add_generator}, \link{get_mon_arrivals},
 #' \link{get_mon_resources}, \link{get_n_generated}, \link{get_capacity}, \link{get_queue_size},
@@ -393,15 +454,16 @@ get_mon_attributes <- function(env) envs_apply(env, "get_mon_attributes")
 #' Gets the resources' monitored data (if any).
 #' 
 #' @param env the simulation environment (or a list of environments).
+#' @param data whether to retrieve the "counts", the "limits" or both.
 #' 
 #' @return Returns a data frame.
-#' @seealso Other methods to deal with a simulation environment:
+#' @seealso Other methods for dealing with a simulation environment:
 #' \link{simmer}, \link{reset}, \link{now}, \link{peek}, \link{onestep}, \link{run}, 
 #' \link{add_resource}, \link{add_generator}, \link{get_mon_arrivals}, \link{get_mon_attributes},
 #' \link{get_n_generated}, \link{get_capacity}, \link{get_queue_size},
 #' \link{get_server_count}, \link{get_queue_count}.
 #' @export
-get_mon_resources <- function(env) envs_apply(env, "get_mon_resources")
+get_mon_resources <- function(env, data="counts") envs_apply(env, "get_mon_resources", data)
 
 #' Get the number of arrivals generated
 #'
@@ -411,7 +473,7 @@ get_mon_resources <- function(env) envs_apply(env, "get_mon_resources")
 #' @param name the name of the generator.
 #' 
 #' @return Returns a numeric value.
-#' @seealso Other methods to deal with a simulation environment:
+#' @seealso Other methods for dealing with a simulation environment:
 #' \link{simmer}, \link{reset}, \link{now}, \link{peek}, \link{onestep}, \link{run}, 
 #' \link{add_resource}, \link{add_generator}, \link{get_mon_arrivals}, \link{get_mon_attributes},
 #' \link{get_mon_resources}, \link{get_capacity}, \link{get_queue_size},
@@ -427,7 +489,7 @@ get_n_generated <- function(env, name) env$get_n_generated(name)
 #' @param name the name of the resource.
 #' 
 #' @return Returns a numeric value.
-#' @seealso Other methods to deal with a simulation environment:
+#' @seealso Other methods for dealing with a simulation environment:
 #' \link{simmer}, \link{reset}, \link{now}, \link{peek}, \link{onestep}, \link{run}, 
 #' \link{add_resource}, \link{add_generator}, \link{get_mon_arrivals}, \link{get_mon_attributes},
 #' \link{get_mon_resources}, \link{get_n_generated}, \link{get_queue_size},
@@ -443,7 +505,7 @@ get_capacity <- function(env, name) env$get_capacity(name)
 #' @param name the name of the resource.
 #' 
 #' @return Returns a numeric value.
-#' @seealso Other methods to deal with a simulation environment:
+#' @seealso Other methods for dealing with a simulation environment:
 #' \link{simmer}, \link{reset}, \link{now}, \link{peek}, \link{onestep}, \link{run}, 
 #' \link{add_resource}, \link{add_generator}, \link{get_mon_arrivals}, \link{get_mon_attributes},
 #' \link{get_mon_resources}, \link{get_n_generated}, \link{get_capacity},
@@ -459,7 +521,7 @@ get_queue_size <- function(env, name) env$get_queue_size(name)
 #' @param name the name of the resource.
 #' 
 #' @return Returns a numeric value.
-#' @seealso Other methods to deal with a simulation environment:
+#' @seealso Other methods for dealing with a simulation environment:
 #' \link{simmer}, \link{reset}, \link{now}, \link{peek}, \link{onestep}, \link{run}, 
 #' \link{add_resource}, \link{add_generator}, \link{get_mon_arrivals}, \link{get_mon_attributes},
 #' \link{get_mon_resources}, \link{get_n_generated}, \link{get_capacity}, \link{get_queue_size},
@@ -475,7 +537,7 @@ get_server_count <- function(env, name) env$get_server_count(name)
 #' @param name the name of the resource.
 #' 
 #' @return Returns a numeric value.
-#' @seealso Other methods to deal with a simulation environment:
+#' @seealso Other methods for dealing with a simulation environment:
 #' \link{simmer}, \link{reset}, \link{now}, \link{peek}, \link{onestep}, \link{run}, 
 #' \link{add_resource}, \link{add_generator}, \link{get_mon_arrivals}, \link{get_mon_attributes},
 #' \link{get_mon_resources}, \link{get_n_generated}, \link{get_capacity}, \link{get_queue_size},
