@@ -90,7 +90,7 @@ template <typename T>
 class Release: public Activity {
 public:
   Release(std::string resource, T amount, bool provide_attrs):
-    Activity("Release", resource, provide_attrs, -1), amount(amount) {}
+    Activity("Release", resource, provide_attrs, PRIORITY_RELEASE), amount(amount) {}
   
   void print(int indent=0);
   double run(Arrival* arrival);
@@ -106,7 +106,7 @@ template <typename T>
 class SetAttribute: public Activity {
 public:
   SetAttribute(std::string key, T value, bool provide_attrs):
-    Activity("SetAttribute", "none", provide_attrs), key(key), value(value) {}
+    Activity("SetAttribute", "-", provide_attrs), key(key), value(value) {}
   
   void print(int indent=0);
   double run(Arrival* arrival);
@@ -123,7 +123,7 @@ template <typename T>
 class Timeout: public Activity {
 public:
   Timeout(T delay, bool provide_attrs):
-    Activity("Timeout", "none", provide_attrs), delay(delay) {}
+    Activity("Timeout", "-", provide_attrs), delay(delay) {}
   
   void print(int indent=0);
   double run(Arrival* arrival);
@@ -139,17 +139,14 @@ private:
 class Branch: public Activity {
 public:
   Branch(Rcpp::Function option, bool provide_attrs, VEC<bool> merge, VEC<Rcpp::Environment> trj):
-    Activity("Branch", "none", provide_attrs), option(option), merge(merge), trj(trj), selected(NULL) {
+    Activity("Branch", "-", provide_attrs), option(option), merge(merge), trj(trj), selected(NULL) {
     n = 0;
-    for (unsigned int i = 0; i < trj.size(); i++) {
-      Rcpp::Function get_head(trj[i]["get_head"]);
-      path.push_back(Rcpp::as<Rcpp::XPtr<Activity> >(get_head()));
-      if (merge[i]) {
-        Rcpp::Function get_tail(trj[i]["get_tail"]);
-        Rcpp::XPtr<Activity> tail(get_tail());
-        tail->set_next(this);
-      }
-      Rcpp::Function get_n_activities(trj[i]["get_n_activities"]);
+    foreach_ (VEC<Rcpp::Environment>::value_type& itr, trj) {
+      Rcpp::Function get_head(itr["get_head"]);
+      Rcpp::Function get_tail(itr["get_tail"]);
+      heads.push_back(Rcpp::as<Rcpp::XPtr<Activity> >(get_head()));
+      tails.push_back(Rcpp::as<Rcpp::XPtr<Activity> >(get_tail()));
+      Rcpp::Function get_n_activities(itr["get_n_activities"]);
       n += Rcpp::as<int>(get_n_activities());
     }
   }
@@ -165,6 +162,19 @@ public:
   
   double run(Arrival* arrival);
   
+  void set_prev(Activity* activity) {
+    Activity::set_prev(activity);
+    foreach_ (VEC<Activity*>::value_type& itr, heads)
+      itr->set_prev(activity);
+  }
+  
+  void set_next(Activity* activity) {
+    Activity::set_next(activity);
+    for (unsigned int i = 0; i < tails.size(); i++) {
+      if (merge[i]) tails[i]->set_next(activity);
+    }
+  }
+  
   Activity* get_next() {
     if (selected) {
       Activity* aux = selected;
@@ -179,8 +189,8 @@ private:
   VEC<bool> merge;
   VEC<Rcpp::Environment> trj;
   Activity* selected;
-  VEC<Activity*> path;
-  USET<Arrival*> pending;
+  VEC<Activity*> heads;
+  VEC<Activity*> tails;
 };
 
 /**
@@ -190,7 +200,7 @@ template <typename T>
 class Rollback: public Activity {
 public:
   Rollback(int amount, T times, bool provide_attrs):
-    Activity("Rollback", "none", provide_attrs), amount(std::abs(amount)), times(times),
+    Activity("Rollback", "-", provide_attrs), amount(std::abs(amount)), times(times),
     cached(NULL), selected(NULL) {}
   
   void print(int indent=0);
@@ -211,7 +221,7 @@ private:
   Activity* cached, *selected;
   UMAP<Arrival*, int> pending;
   
-  inline Activity* goback() {
+  Activity* goback() {
     int n = amount;
     Activity* ptr = this;
     while (ptr->get_prev() && n--)
