@@ -2,10 +2,8 @@
 #define SIMULATOR_H
 
 #include "simmer.h"
-#include "entity.h"
-
-// forward declarations
-class Activity;
+#include "process.h"
+#include "resource.h"
 
 /**
  * The simulator.
@@ -24,12 +22,13 @@ class Simulator {
     
     bool operator<(const Event& other) const {
       if (time == other.time)
-        return priority > other.priority;
-      return time > other.time;
+        return priority < other.priority;
+      return time < other.time;
     }
   };
   
-  typedef PQUEUE<Event> PQueue;
+  typedef MSET<Event> PQueue;
+  typedef UMAP<Process*, PQueue::iterator> EvMap;
   typedef UMAP<std::string, Entity*> EntMap;
   
 public:
@@ -44,32 +43,30 @@ public:
   Simulator(std::string name, bool verbose): name(name), verbose(verbose), now_(0) {}
   
   ~Simulator() {
-    while (!event_queue.empty()) {
-      if (!event_queue.top().process->is_generator())
-        delete event_queue.top().process;
-      event_queue.pop();
-    }
+    foreach_ (PQueue::value_type& itr, event_queue)
+      if (itr.process->is_arrival()) delete itr.process;
+    event_queue.clear();
+    event_map.clear();
   }
   
   /**
-   * Reset the simulation: time, event queue, resources, generators and statistics.
+   * Reset the simulation: time, event queue, resources, processes and statistics.
    */
   void reset() {
     now_ = 0;
-    while (!event_queue.empty()) {
-      if (!event_queue.top().process->is_generator())
-        delete event_queue.top().process;
-      event_queue.pop();
-    }
+    foreach_ (PQueue::value_type& itr, event_queue)
+      if (itr.process->is_arrival()) delete itr.process;
+    event_queue.clear();
+    event_map.clear();
     foreach_ (EntMap::value_type& itr, resource_map)
       ((Resource*)itr.second)->reset();
-    foreach_ (EntMap::value_type& itr, generator_map) {
-      ((Generator*)itr.second)->reset();
-      ((Generator*)itr.second)->run();
+    foreach_ (EntMap::value_type& itr, process_map) {
+      ((Process*)itr.second)->reset();
+      ((Process*)itr.second)->run();
     }
   }
   
-  inline double now() { return now_; }
+  double now() { return now_; }
   
   /**
    * Schedule a future event.
@@ -77,27 +74,39 @@ public:
    * @param   process   the process to schedule
    * @param   priority  additional key to execute releases before seizes if they coincide
    */
-  inline void schedule(double delay, Process* process, int priority=0) {
-    event_queue.push(Event(now_ + delay, process, priority));
+  void schedule(double delay, Process* process, int priority=0) {
+    event_map[process] = event_queue.emplace(now_ + delay, process, priority);
+  }
+  
+  void unschedule(Process* process) {
+    event_queue.erase(event_map[process]);
+    event_map.erase(process);
   }
   
   /**
-   * Get the time of the next scheduled event.
+   * Look for future events.
    */
-  double peek() { 
-    if (!event_queue.empty())
-      return event_queue.top().time;
-    else return -1;
+  std::pair<VEC<double>, VEC<std::string> > peek(int steps) {
+    VEC<double> time;
+    VEC<std::string> process;
+    if (steps) { foreach_ (PQueue::value_type& itr, event_queue) {
+      time.push_back(itr.time);
+      process.push_back(itr.process->name);
+      if (!--steps) break;
+    }}
+    return std::make_pair(time, process);
   }
   
   /**
    * Process the next event. Only one step, a giant leap for mankind.
    */
-  inline bool step() {
+  bool step() {
     if (event_queue.empty()) return 0;
-    now_ = event_queue.top().time;
-    event_queue.top().process->run();
-    event_queue.pop();
+    PQueue::iterator ev = event_queue.begin();
+    event_map.erase(ev->process);
+    now_ = ev->time;
+    ev->process->run();
+    event_queue.erase(ev);
     return 1;
     // ... and that's it! :D
   }
@@ -108,7 +117,7 @@ public:
    */
   void run(double until) {
     long int nsteps = 0;
-    while ((now_ < until) && step())
+    while ((now_ < until || until < 0) && step())
       if (++nsteps % 100000 == 0)
         Rcpp::checkUserInterrupt();
   }
@@ -122,13 +131,13 @@ public:
    */
   bool add_generator(std::string name_prefix, 
                      Activity* first_activity, Rcpp::Function dist, int mon) {
-    if (generator_map.find(name_prefix) == generator_map.end()) {
+    if (process_map.find(name_prefix) == process_map.end()) {
       Generator* gen = new Generator(this, name_prefix, mon, first_activity, dist);
-      generator_map[name_prefix] = gen;
+      process_map[name_prefix] = gen;
       gen->run();
       return TRUE;
     }
-    Rcpp::warning("generator " + name + " already defined");
+    Rcpp::warning("process " + name + " already defined");
     return FALSE;
   }
   
@@ -160,12 +169,42 @@ public:
     return FALSE;
   }
   
+  /**
+   * Add a process that manages the capacity or the queue_size of a resource
+   * given a scheduling.
+   * @param   name      the resource name
+   * @param   param     "capacity" or "queue_size"
+   * @param   duration  vector of durations until the next value change
+   * @param   value     vector of values
+   */
+  bool add_resource_manager(std::string name, std::string param, 
+                            VEC<double> duration, VEC<int> value, int period) {
+    if (process_map.find(name) == process_map.end()) {
+      EntMap::iterator search = resource_map.find(name);
+      if (search == resource_map.end())
+        Rcpp::stop("resource '" + name + "' not found (typo?)");
+      Resource* res = (Resource*)search->second;
+      
+      Manager* manager;
+      if (param.compare("capacity") == 0)
+        manager = new Manager(this, name, param, duration, value, period,
+                                   boost::bind(&Resource::set_capacity, res, _1));
+      else manager = new Manager(this, name, param, duration, value, period,
+                                      boost::bind(&Resource::set_queue_size, res, _1));
+      process_map[name + "_" + param] = manager;
+      manager->run();
+      return TRUE;
+    }
+    Rcpp::warning("process " + name + " already defined");
+    return FALSE;
+  }
+  
   /**
    * Get a generator by name.
    */
   Generator* get_generator(std::string name) {
-    EntMap::iterator search = generator_map.find(name);
-    if (search == generator_map.end())
+    EntMap::iterator search = process_map.find(name);
+    if (search == process_map.end())
       Rcpp::stop("generator '" + name + "' not found (typo?)");
     return (Generator*)search->second;
   }
@@ -184,7 +223,8 @@ private:
   double now_;              /**< simulation time */
   PQueue event_queue;       /**< the event queue */
   EntMap resource_map;      /**< map of resources */
-  EntMap generator_map;     /**< map of generators */
+  EntMap process_map;       /**< map of processes */
+  EvMap event_map;          /**< map of pending events */
 };
 
 #endif
