@@ -51,12 +51,11 @@ test_that("resource slots are correctly filled", {
   
   expect_equal(arrivals[3,]$finished, FALSE)
   expect_equal(nrow(arrivals_res), 0)
-  expect_equal(resources[5,]$server, 2)
-  expect_equal(resources[5,]$queue, 2)
+  expect_equal(resources[4,]$server, 2)
+  expect_equal(resources[4,]$queue, 2)
   expect_equal(sum(attributes$value), 2)
 })
 
-
 test_that("resources are  correctly monitored", {
   t0 <- create_trajectory("") %>%
     seize("server", 1) %>%
@@ -69,79 +68,29 @@ test_that("resources are  correctly monitored", {
   
   resources <- env%>%get_mon_resources()
   
-  expect_equal(resources[2,]$server, 1) # to be discussed: debatable whether or not it should equal 1 or 0
+  expect_equal(resources[1,]$server, 1)
+  expect_equal(resources[2,]$server, 0)
 })
 
-test_that("priority queues are adhered to (1)", {
-  t0 <- create_trajectory("nonprior") %>%
-    seize("server", 1, priority=0) %>%
-    timeout(2) %>%
-    release("server", 1)
-  
-  t1 <- create_trajectory("prior") %>%
-    seize("server", 1, priority=1) %>%
-    timeout(2) %>%
+test_that("a big departure triggers more than one small seize from the queue", {
+  t0 <- create_trajectory("") %>%
+    seize("server", 2) %>%
+    timeout(10) %>%
+    release("server", 2)
+  t1 <- create_trajectory("") %>%
+    seize("server", 1) %>%
+    timeout(10) %>%
     release("server", 1)
   
   env <- simmer() %>%
-    add_resource("server", 1) %>%
-    add_generator("__nonprior", t0, at(c(0, 1))) %>%
-    add_generator("__prior", t1, at(1)) %>% # should be served second
+    add_resource("server", 2) %>%
+    add_generator("a", t0, at(0)) %>%
+    add_generator("b", t1, at(1, 2)) %>%
     run()
   
-  arrs <-
-    env%>%get_mon_arrivals()
-    
-  expect_equal(arrs[arrs$name=="__prior0",]$end_time, 4)
-})
-
-test_that("priority queues are adhered to (2)", {
-  t0 <- create_trajectory("nonprior") %>%
-    seize("server", 1, priority=0) %>%
-    timeout(2) %>%
-    release("server", 1)
+  arrs <- env%>%get_mon_arrivals()
+  arrs_ordered <- arrs[order(arrs$name),]
   
-  t1 <- create_trajectory("prior") %>%
-    seize("server", 1, priority=1) %>%
-    timeout(2) %>%
-    release("server", 1)
-  
-  env <- simmer() %>%
-    add_resource("server", 1) %>%
-    add_generator("__nonprior", t0, at(c(0, 0))) %>%
-    add_generator("__prior", t1, at(1)) %>% # should be served second
-    run()
-  
-  arrs <-
-    env%>%get_mon_arrivals()
-    
-  expect_equal(arrs[arrs$name=="__prior0",]$end_time, 4) 
-})
-
-test_that("priority queues are adhered to and same level priorities are processed FIFO", {
-  t0 <- create_trajectory("_t0_prior") %>%
-    seize("server", 1, priority=1) %>%
-    timeout(2) %>%
-    release("server", 1)
-  
-  t1 <- create_trajectory("_t1_prior") %>%
-    seize("server", 1, priority=1) %>%
-    timeout(2) %>%
-    release("server", 1)
-  
-  env <- simmer() %>%
-    add_resource("server", 1) %>%
-    add_generator("_t0_prior", t0, at(c(0, 2, 4, 6))) %>%
-    add_generator("_t1_prior", t1, at(c(1, 3, 5, 7))) %>%
-    run()
-  
-  arrs <-
-    env%>%get_mon_arrivals()
-  
-  arrs_ordered <-
-    arrs[order(arrs$end_time),]
-    
-  expect_equal(as.character(arrs_ordered$name), 
-                c("_t0_prior0", "_t1_prior0", "_t0_prior1", "_t1_prior1", 
-                  "_t0_prior2", "_t1_prior2", "_t0_prior3", "_t1_prior3"))
+  expect_equal(as.character(arrs_ordered$name), c("a0", "b0", "b1"))
+  expect_equal(arrs_ordered$end_time, c(10, 20, 20))
 })
